#!/bin/sh

if [ "X$1" = 'X-h' ] || [ "X$1" = 'X--help' ]; then
  echo 'Usage: control.sh [-h] [-a VARIANT] [PV_PREFIX [DEVICE_NAME]]'
  echo 'Options:'
  echo '  -h           Print a help message and exit'
  echo '  -a VARIANT   Hardware variant (default: 1)'
  echo 'Parameters:'
  echo '  PV_PREFIX    PV name prefix (default: "ioc23:")'
  echo '  DEVICE_NAME  Name of device (default: "websen1")'
  echo 'Example: control.sh'
  echo 'Example: control.sh ioc1: websen2'
  exit 0
fi

variant=1
while getopts a: opt; do
  case $opt in
     a)  variant=$OPTARG ;;
    \?)  echo "Illegal option: $OPTARG" 1>&2; exit 1 ;;
  esac
done
shift $((OPTIND - 1))

if [ "X$variant" != 'X1' ] && [ "X$variant" != 'X2' ]; then
  echo "Illegal -a argument: $variant" 1>&2
  exit 1
fi

pvPrefix=ioc23:
if [ "X$1" != 'X' ]; then pvPrefix="$1"; fi
deviceName=websen1
if [ "X$2" != 'X' ]; then deviceName="$2"; fi

adl_filename=websensor-em01b.adl
if [ "X$variant" != 'X1' ]; then
  adl_filename="websensor-em01b-var-$variant.adl"
fi

thisScriptHome=`dirname "$0"`
cd "$thisScriptHome"
if [ $? -ne 0 ]; then
  echo "Failed to cd to \"$thisScriptHome\"." 1>&2
  exit 1
fi
thisScriptHome=`pwd`
if [ $? -ne 0 ]; then
  echo 'Failed to get current working directory.' 1>&2
  exit 1
fi

cd "../src"
if [ $? -ne 0 ]; then
  echo "Failed to cd to \"$thisScriptHome/../src\"." 1>&2
  exit 1
fi

exec medm -x -macro "P=$pvPrefix,D=$deviceName" "./$adl_filename"
