#!/usr/bin/env python

#
# Usage: python em01b-comp-tidx.py HOST [PORT]
#
# Sends "em" command to websensor and computes TIDX macro value for use in
# websensor-em01b.db.
#
# Example:
# $ python em01b-comp-tidx.py localhost
#

import os
import socket
import sys

DEFAULT_PORT = 80
EM_REQUEST = "GET /index.html?em HTTP/1.0\r\n\r\n"
RECEIVE_BUFFER_SIZE = 256

def main():
  (host, port) = getCommandLineArgs()
  s = createConnectedSocket(host, port)
  s.send(EM_REQUEST)
  print >> sys.stderr, "> \"%s\"" % EM_REQUEST.encode("string_escape")
  sys.stderr.flush()
  response = s.recv(RECEIVE_BUFFER_SIZE)
  print >> sys.stderr, "< \"%s\"" % response.encode("string_escape")
  sys.stderr.flush()
  s.close()
  tidx = response.find("TC:")
  if tidx == -1: tidx = response.find("TF:")
  if tidx != -1:
    print >> sys.stderr, "TIDX=%d" % tidx
  else:
    print >> sys.stderr, 'error: couldn\'t find "TC:" nor "TF:" in response'
    sys.exit(1)

def createConnectedSocket(host, port):
  s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
  s.connect((host, port))
  return s

def getCommandLineArgs():
  if len(sys.argv) <= 1:
    print >> sys.stderr, "error: expected HOST argument"
    sys.exit(1)
  host = sys.argv[1]
  port = DEFAULT_PORT
  if len(sys.argv) > 2: port = int(sys.argv[2])
  return (host, port)

if __name__ == "__main__": main()
